@@ -10,10 +10,8 @@
 #define COPY_ACCEL "<CTRL><SHIFT>C"
 #define PASTE_ACCEL "<CTRL><SHIFT>V"
 #define RENAME_TAB_ACCEL "<CTRL><SHIFT>R"
-#define PREVIOUS_TAB_ACCEL "<CTRL>Page_Up"
-#define NEXT_TAB_ACCEL "<CTRL>Page_Down"
-#define PREVIOUS_TAB_ACCEL_GNOME "<CTRL><SHIFT>Page_Down"
-#define NEXT_TAB_ACCEL_GNOME "<CTRL><SHIFT>Page_Up"
+#define PREVIOUS_TAB_ACCEL "<CTRL><SHIFT>Page_Down"
+#define NEXT_TAB_ACCEL "<CTRL><SHIFT>Page_Up"
 #define SWITCH_TAB1_ACCEL "<ALT>1"
 #define SWITCH_TAB2_ACCEL "<ALT>2"
 #define SWITCH_TAB3_ACCEL "<ALT>3"
@@ -48,6 +46,10 @@ typedef struct _lxterminal {
 	GdkGeometry geometry;
 	GdkWindowHints geom_mask;
 	gboolean fixedsize;
+	gboolean rgba;
+	GdkColor background;
+	GdkColor foreground;
+	gint     tabpos;
 } LXTerminal;
 
 typedef struct _tab {
@@ -66,15 +68,15 @@ typedef struct _term {
 } Term;
 
 
-Term *terminal_new(LXTerminal *terminal, const gchar *label, const gchar *pwd, const gchar **env, const gchar *exec);
-void terminal_newwindow(gpointer data, guint action, GtkWidget *item);
-void terminal_newtab(gpointer data, guint action, GtkWidget *item);
-void terminal_closetab(gpointer data, guint action, GtkWidget *item);
-void terminal_nexttab(gpointer data, guint action, GtkWidget *item);
-void terminal_prevtab(gpointer data, guint action, GtkWidget *item);
-void terminal_about( gpointer data, guint action, GtkWidget* item );
-gboolean terminal_copy(gpointer data, guint action, GtkWidget *item);
-gboolean terminal_paste(gpointer data, guint action, GtkWidget *item);
+Term *terminal_new(LXTerminal *terminal, const gchar *label, const gchar *pwd, gchar **env, const gchar *exec);
+void terminal_newwindow(GtkAction *action, gpointer data);
+void terminal_newtab(GtkWidget *widget, gpointer data);
+void terminal_closetab(GtkAction *action, gpointer data);
+void terminal_nexttab(GtkAction *action, gpointer data);
+void terminal_prevtab(GtkAction *action, gpointer data);
+void terminal_about(GtkAction *action, gpointer data);
+gboolean terminal_copy(GtkAction *action, gpointer data);
+gboolean terminal_paste(GtkAction *action, gpointer data);
 
 void terminal_setting_update(LXTerminal *terminal, Setting *setting);
 
